<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sl">
<context>
    <name>AsciiFile</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="35"/>
        <location filename="../asciifile/asciifile.cpp" line="41"/>
        <source>Read ascii points</source>
        <translation>Preberi ascii točke</translation>
    </message>
</context>
<context>
    <name>ImportShp</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="40"/>
        <source>Import ESRI Shapefile</source>
        <translation>Uvozi ESRi datoteko oblike</translation>
    </message>
</context>
<context>
    <name>LC_Align</name>
    <message>
        <location filename="../align/align.cpp" line="20"/>
        <location filename="../align/align.cpp" line="27"/>
        <source>Align</source>
        <translation>Poravnava</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="40"/>
        <source>first base point:</source>
        <translation>prva bazna točka:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="42"/>
        <source>first target point:</source>
        <translation>prva ciljna točka:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="44"/>
        <source>second base point:</source>
        <translation>sekundarna bazna točka:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="46"/>
        <source>second target point:</source>
        <translation>sekundarna ciljna točka:</translation>
    </message>
</context>
<context>
    <name>LC_Gear</name>
    <message>
        <location filename="../gear/gear.cpp" line="33"/>
        <source>Gear creation plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="40"/>
        <source>Gear plugin</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LC_List</name>
    <message>
        <location filename="../list/list.cpp" line="23"/>
        <location filename="../list/list.cpp" line="30"/>
        <source>List entities</source>
        <translation>Seznam entitet</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="46"/>
        <source>n</source>
        <translation>n</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="60"/>
        <source>Empty Entity</source>
        <translation>Prazna entiteta</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="77"/>
        <source>Layer</source>
        <translation>Plast</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="79"/>
        <source>Color</source>
        <translation>Barva</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="80"/>
        <source>Line type</source>
        <translation>Vrsta črte</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="81"/>
        <source>Line thickness</source>
        <translation>Debelina črte</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="82"/>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="88"/>
        <source>POINT</source>
        <translation>TOČKA</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="89"/>
        <location filename="../list/list.cpp" line="218"/>
        <source>in point</source>
        <translation>v točka</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="94"/>
        <source>LINE</source>
        <translation>ČRTA</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="99"/>
        <source>from point</source>
        <translation>od točke</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="102"/>
        <source>to point</source>
        <translation>k točki</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="107"/>
        <location filename="../list/list.cpp" line="131"/>
        <source>length</source>
        <translation>dolžina</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="112"/>
        <source>Angle in XY plane</source>
        <translation>Kot v XY ravnini</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="113"/>
        <source>Inc.</source>
        <translation>lnc.</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="118"/>
        <source>ARC</source>
        <translation>LOK</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="119"/>
        <location filename="../list/list.cpp" line="135"/>
        <location filename="../list/list.cpp" line="145"/>
        <source>center point</source>
        <translation>središčna točka</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="125"/>
        <location filename="../list/list.cpp" line="139"/>
        <location filename="../list/list.cpp" line="222"/>
        <source>radius</source>
        <translation>polmer</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="126"/>
        <source>initial angle</source>
        <translation>začetni kot</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="127"/>
        <source>final angle</source>
        <translation>končni kot</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="134"/>
        <source>CIRCLE</source>
        <translation>KROŽNICA</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="140"/>
        <source>circumference</source>
        <translation>obseg</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="141"/>
        <source>area</source>
        <translation>ploščina</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="144"/>
        <source>ELLIPSE</source>
        <translation>ELIPSA</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="148"/>
        <source>major axis</source>
        <translation>glavna os</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="166"/>
        <source>CONSTRUCTIONLINE</source>
        <translation>KONSTRUKCIJSKA ČRTA</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="169"/>
        <source>OVERLAYBOX</source>
        <translation>PREKRIVNO OKENCE</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="172"/>
        <source>SOLID</source>
        <translation>TELO</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="176"/>
        <source>MTEXT</source>
        <translation>MTEXT</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="179"/>
        <source>TEXT</source>
        <translation>TEKST</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="182"/>
        <source>INSERT</source>
        <translation>VSTAVI</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="185"/>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="187"/>
        <source>Insertion point</source>
        <translation>Točka vstavljanja</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="190"/>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="193"/>
        <source>Rotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="199"/>
        <source>Columns/Rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="203"/>
        <source>Column/Row Spacing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="210"/>
        <source>POLYLINE</source>
        <translation>LOMLJENKA</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="211"/>
        <source>Closed</source>
        <translation>Zaključeno</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="212"/>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="212"/>
        <source>Yes</source>
        <translation>Da</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="213"/>
        <source>Vertices</source>
        <translation>Točke</translation>
    </message>
    <message>
        <source>curvature</source>
        <translation type="obsolete">ukrivljenost</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="227"/>
        <source>IMAGE</source>
        <translation>SLIKA</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="230"/>
        <source>SPLINE</source>
        <translation>KRIVULJA</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="233"/>
        <source>SPLINEPOINTS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="236"/>
        <source>HATCH</source>
        <translation>LOPUTA</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="239"/>
        <source>DIMLEADER</source>
        <translation>PREHOD</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="242"/>
        <source>DIMALIGNED</source>
        <translation>Vodilo prehoda</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="245"/>
        <source>DIMLINEAR</source>
        <translation>Linearni prehod</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="248"/>
        <source>DIMRADIAL</source>
        <translation>Radialni prehod</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="251"/>
        <source>DIMDIAMETRIC</source>
        <translation>Prehod v smeri premera</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="254"/>
        <source>DIMANGULAR</source>
        <translation>Kotni prehod</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="257"/>
        <source>UNKNOWN</source>
        <translation>NEZNANO</translation>
    </message>
</context>
<context>
    <name>LC_SameProp</name>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="21"/>
        <location filename="../sameprop/sameprop.cpp" line="28"/>
        <source>Same properties</source>
        <translation>Enake lastnosti</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="41"/>
        <source>select original entity:</source>
        <translation>izberi začetno entiteto:</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="43"/>
        <source>select entities to change</source>
        <translation>izberi entitete za spreminjanje</translation>
    </message>
</context>
<context>
    <name>LC_Sample</name>
    <message>
        <location filename="../sample/sample.cpp" line="26"/>
        <location filename="../sample/sample.cpp" line="33"/>
        <source>Sample plugin</source>
        <translation>Vzorčni vtičnik</translation>
    </message>
</context>
<context>
    <name>PicFile</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="36"/>
        <source>Read PIC file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="42"/>
        <source>import PIC file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dibPunto</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="229"/>
        <source>Read ascii points</source>
        <translation>Preberi ascii točke</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="235"/>
        <source>File...</source>
        <translation>Datoteka...</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="242"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Space Separator</source>
        <translation>Oznaka razmika</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Tab Separator</source>
        <translation>Oznaka tabulatorja</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Comma Separator</source>
        <translation>Oznaka vejice</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Space in Columns</source>
        <translation>Razmik v stolpcih</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>*.odb for Psion 2</source>
        <translation>*.odb za Psion 2</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="246"/>
        <source>Connect points</source>
        <translation>Poveži točke</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="254"/>
        <source>2D Point</source>
        <translation>2D točke</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="254"/>
        <source>Draw 2D Point</source>
        <translation>Nariši 2D točko</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="255"/>
        <source>3D Point</source>
        <translation>3D točka</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="255"/>
        <source>Draw 3D Point</source>
        <translation>Nariši 3D točko</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="256"/>
        <source>Point Number</source>
        <translation>Številka točke</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="256"/>
        <source>Draw point number</source>
        <translation>Nariši številko točke</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="257"/>
        <source>Point Elevation</source>
        <translation>Višina točke</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="257"/>
        <source>Draw point elevation</source>
        <translation>Nariši višino točke</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="258"/>
        <source>Point Code</source>
        <translation>Koda točke</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="258"/>
        <source>Draw point code</source>
        <translation>Nariši kodo točke</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="272"/>
        <source>Accept</source>
        <translation>Sprejmi</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="277"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="307"/>
        <source>Select file</source>
        <translation>Izberi datoteko</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="314"/>
        <source>Point 2D layer is empty</source>
        <translation>Točkina 2D plast je prazna</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="317"/>
        <source>Point 3D layer is empty</source>
        <translation>Točkina 3D plast je prazna</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="320"/>
        <source>Point elevation layer is empty</source>
        <translation>Plast višine točke je prazna</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="321"/>
        <source>Point elevation height is empty</source>
        <translation>Višina točke je prazna</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="322"/>
        <source>Point elevation separation is empty</source>
        <translation>Odmik točkine višine je prazen</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="325"/>
        <source>Point number layer is empty</source>
        <translation>Plast številke točke je prazna</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="326"/>
        <source>Point number height is empty</source>
        <translation>Višina točkine številke je prazna</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="327"/>
        <source>Point number separation is empty</source>
        <translation>Odmik številke točke je prazen</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="330"/>
        <source>Point code layer is empty</source>
        <translation>Plast kode točke je prazna</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="331"/>
        <source>Point code height is empty</source>
        <translation>Višina kode točke je prazna</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="332"/>
        <source>Point code separation is empty</source>
        <translation>Odmik kode točke je prazen</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="360"/>
        <source>The file %1 not exist</source>
        <translation>Datoteka %1 ne obstaja</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="365"/>
        <source>Can&apos;t open the file %1</source>
        <translation>Ne morem odpreti datoteke %1</translation>
    </message>
</context>
<context>
    <name>dibSHP</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="59"/>
        <source>File...</source>
        <translation>Datoteka...</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="67"/>
        <source>File type:</source>
        <translation>Vrsta datoteke:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="75"/>
        <source>Layer</source>
        <translation>Plast</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="56"/>
        <source>Import ESRI Shapefile</source>
        <translation>Uvozi ESRI datoteko telesa</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="68"/>
        <location filename="../importshp/importshp.cpp" line="266"/>
        <source>Unknown</source>
        <translation>Neznano</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="76"/>
        <location filename="../importshp/importshp.cpp" line="89"/>
        <location filename="../importshp/importshp.cpp" line="102"/>
        <location filename="../importshp/importshp.cpp" line="115"/>
        <source>Current</source>
        <translation>Trenutno</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="77"/>
        <location filename="../importshp/importshp.cpp" line="90"/>
        <location filename="../importshp/importshp.cpp" line="103"/>
        <location filename="../importshp/importshp.cpp" line="116"/>
        <source>From data:</source>
        <translation>Iz podatkov:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="88"/>
        <source>Color</source>
        <translation>Barva</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="101"/>
        <source>Line type</source>
        <translation>Vrsta črte</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="114"/>
        <source>Width</source>
        <translation>Širina</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="127"/>
        <location filename="../importshp/importshp.cpp" line="213"/>
        <source>Point</source>
        <translation>Točka</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="128"/>
        <source>as Point</source>
        <translation>kot točka</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="129"/>
        <source>as Label:</source>
        <translation>kot oznaka:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="141"/>
        <source>Accept</source>
        <translation>Sprejmem</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="142"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="167"/>
        <source>Select file</source>
        <translation>Izberi datoteko</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="217"/>
        <source>Point+Measure</source>
        <translation>Točka+meritev</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="221"/>
        <source>3D Point</source>
        <translation>3D točka</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="225"/>
        <source>Multi Point</source>
        <translation>Več točk</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="229"/>
        <source>Multi Point+Measure</source>
        <translation>Več točk + meritve</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="233"/>
        <source>3D Multi Point</source>
        <translation>3D več točk</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="237"/>
        <source>Arc</source>
        <translation>Lok</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="241"/>
        <source>Arc+Measure</source>
        <translation>Lok + Meritev</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="245"/>
        <source>3D Arc</source>
        <translation>3D lok</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="249"/>
        <source>Polygon</source>
        <translation>Poligon</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="253"/>
        <source>Polygon+Measure</source>
        <translation>Poligon + Meritve</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="257"/>
        <source>3D Polygon</source>
        <translation>3D poligon</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="261"/>
        <source>Multipatch</source>
        <translation>Več popravkov</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="281"/>
        <source>The file %1 not have extension .shp</source>
        <translation>Datoteka %1 nima končnice .shp</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="286"/>
        <source>The file %1 not exist</source>
        <translation>Datoteka %1 ne obstaja</translation>
    </message>
</context>
<context>
    <name>lc_Geardlg</name>
    <message>
        <location filename="../gear/gear.cpp" line="66"/>
        <source>Draw a gear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="71"/>
        <source>Number of teeth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="79"/>
        <source>Circular pitch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="87"/>
        <source>Pressure angle (deg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="95"/>
        <source>Addendum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="103"/>
        <source>Dedendum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="111"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="114"/>
        <source>Spur</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="115"/>
        <source>Ring</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="119"/>
        <source>Accept</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="124"/>
        <source>Cancel</source>
        <translation type="unfinished">Prekliči</translation>
    </message>
</context>
<context>
    <name>lc_Listdlg</name>
    <message>
        <location filename="../list/list.cpp" line="274"/>
        <source>List entities</source>
        <translation>Naštej entitete</translation>
    </message>
</context>
<context>
    <name>lc_Sampledlg</name>
    <message>
        <location filename="../sample/sample.cpp" line="54"/>
        <source>Draw line</source>
        <translation>Nariši črto</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="60"/>
        <source>Start X:</source>
        <translation>Začetni X:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="66"/>
        <source>Start Y:</source>
        <translation>Začetni Y:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="72"/>
        <source>End X:</source>
        <translation>Končni X:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="78"/>
        <source>End Y:</source>
        <translation>Končni Y:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="86"/>
        <source>Accept</source>
        <translation>Sprejmem</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="91"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="107"/>
        <source>Start X is empty</source>
        <translation>Začetni X je prazen</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="108"/>
        <source>Start Y is empty</source>
        <translation>Začetni Y je prazen</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="109"/>
        <source>End X is empty</source>
        <translation>Končni X je prazen</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="110"/>
        <source>End Y is empty</source>
        <translation>Končni Y je prazen</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="132"/>
        <source>Sample plugin</source>
        <translation>vzorčni vtičnik</translation>
    </message>
</context>
<context>
    <name>picPunto</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="65"/>
        <source>File...</source>
        <translation type="unfinished">Datoteka...</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="75"/>
        <source>Scale:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="79"/>
        <source>Accept</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="83"/>
        <source>Cancel</source>
        <translation type="unfinished">Prekliči</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="111"/>
        <source>Select file</source>
        <translation type="unfinished">Izberi datoteko</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="119"/>
        <source>Scale Factor is empty or invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="132"/>
        <source>The file %1 not exist</source>
        <translation type="unfinished">Datoteka %1 ne obstaja</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="137"/>
        <source>Can&apos;t open the file %1</source>
        <translation type="unfinished">Ne morem odpreti datoteke %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="144"/>
        <source>%1 objects imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="166"/>
        <source>picPunto drawLine: first point is empty %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="179"/>
        <source>picPunto drawLine: next point is empty %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="258"/>
        <location filename="../picfile/picfile.cpp" line="267"/>
        <source>format error in %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot</name>
    <message>
        <location filename="../plotequation/plot.cpp" line="21"/>
        <location filename="../plotequation/plot.cpp" line="28"/>
        <source>Plot plugin</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plotDialog</name>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="15"/>
        <source>Plot equation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="18"/>
        <source>This plugin allows you to plot mathematical equations.
If you don&apos;t want to use the parametric form, just leave out &quot;Equation2&quot;.
You can use pi when you need the value of pi (i.e. (3*pi)).
Use t or x in your equation as a variable/parameter.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="22"/>
        <source>Equation 1:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="23"/>
        <source>Equation 2:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="26"/>
        <source>start value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="27"/>
        <source>end value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="28"/>
        <source>step size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="32"/>
        <source>Draw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="33"/>
        <source>Cancel</source>
        <translation type="unfinished">Prekliči</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="59"/>
        <source>Line Segments</source>
        <comment>Plot Equation to generate RS_Line segments</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="60"/>
        <source>Polyline</source>
        <comment>Plot Equation to generate RS_Polyline</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="61"/>
        <source>SplinePoints</source>
        <comment>Plot Equation to generate 2nd spline by LC_SplinePoints</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>pointBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="175"/>
        <source>Layer:</source>
        <translation>Plast:</translation>
    </message>
</context>
<context>
    <name>textBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="207"/>
        <source>Style:</source>
        <translation>Slog:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="208"/>
        <source>Height:</source>
        <translation>Višina:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="209"/>
        <source>Separation</source>
        <translation>Razmik</translation>
    </message>
</context>
</TS>
